Learn R Programming

circularEV (version 0.1.2)

circularEV-package: circularEV: Extreme Value Analysis for Circular Data

Description

General functions for performing extreme value analysis on a circular domain as part of the statistical methodology in the paper by Konzen, E., Neves, C., and Jonathan, P. (2021). Modeling nonstationary extremes of storm severity: Comparing parametric and semiparametric inference. Environmetrics, 32(4), e2667 tools:::Rd_expr_doi("10.1002/env.2667").

Arguments

Author

Maintainer: Evandro Konzen circularev.r@gmail.com

Authors: